FermionicAlgebra Type
Implementation of ICombiningAlgebra for fermionic operators using canonical anti-commutation relations (CAR).
Fermions obey the canonical anti-commutation relations:
{a†ᵢ, aⱼ} = a†ᵢ aⱼ + aⱼ a†ᵢ = δᵢⱼ (Kronecker delta) {aᵢ, aⱼ} = aᵢ aⱼ + aⱼ aᵢ = 0 {a†ᵢ, a†ⱼ} = a†ᵢ a†ⱼ + a†ⱼ a†ᵢ = 0
When swapping aᵢ past a†ⱼ during normal ordering:
If i ≠ j: aᵢ a†ⱼ = -a†ⱼ aᵢ (sign flip only) If i = j: aᵢ a†ᵢ = 1 - a†ᵢ aᵢ (generates identity term)
This algebra is used by the normal ordering algorithm to properly account for all terms generated during operator rearrangement.
Constructors
| Constructor |
Description
|
|
|