Header menu logo Encodings

ICombiningAlgebra<'op> Type

Interface for algebras that define how to combine (commute/anti-commute) operators when sorting into normal order.

During normal ordering, operators must be rearranged so that all creation operators appear before all annihilation operators. Each swap may produce additional terms depending on the commutation relations of the algebra.

The Combine method takes a partial product term and the next operator to append, returning all terms that result from the combination (including any terms generated by anti-commutation relations).

Instance members

Instance member Description

this.Combine

Full Usage: this.Combine

Parameters:
    arg0 : P<IxOp<uint32, 'op>>
    arg1 : C<IxOp<uint32, 'op>>

Returns: P<IxOp<uint32, 'op>>[] An array of product terms resulting from the combination, including any additional terms from commutation relations.
Modifiers: abstract

Combines a product term with the next operator unit.

arg0 : P<IxOp<uint32, 'op>>
arg1 : C<IxOp<uint32, 'op>>
Returns: P<IxOp<uint32, 'op>>[]

An array of product terms resulting from the combination, including any additional terms from commutation relations.

Type something to start searching.