Header menu logo Encodings

LadderOperatorProductTerm Type

Represents a product of indexed fermionic ladder operators with a coefficient.

A product term represents an expression like c · a†ᵢ a†ⱼ aₖ aₗ where c is a complex coefficient.

Product terms can be multiplied together and checked for normal/index ordering.

Example string format: "(1+0i)[u0 u1 d3 d2]" for a†₀ a†₁ a₃ a₂

Union cases

Union case Description

LadderProduct PIxOp<uint32, LadderOperatorUnit>

Full Usage: LadderProduct PIxOp<uint32, LadderOperatorUnit>

Parameters:
Item : PIxOp<uint32, LadderOperatorUnit>

Instance members

Instance member Description

this.Coeff

Full Usage: this.Coeff

Returns: Complex
Returns: Complex

this.IsInIndexOrder

Full Usage: this.IsInIndexOrder

Returns: bool
Returns: bool

this.IsInNormalOrder

Full Usage: this.IsInNormalOrder

Returns: bool
Returns: bool

this.Reduce

Full Usage: this.Reduce

Returns: Lazy<P<IxOp<uint32, LadderOperatorUnit>>>
Returns: Lazy<P<IxOp<uint32, LadderOperatorUnit>>>

this.Unapply

Full Usage: this.Unapply

Returns: P<IxOp<uint32, LadderOperatorUnit>>
Returns: P<IxOp<uint32, LadderOperatorUnit>>

this.Units

Full Usage: this.Units

Returns: C<IxOp<uint32, LadderOperatorUnit>>[]
Returns: C<IxOp<uint32, LadderOperatorUnit>>[]

Static members

Static member Description

arg0 * arg1

Full Usage: arg0 * arg1

Parameters:
Returns: LadderOperatorProductTerm

LadderOperatorProductTerm.FromTuples

Full Usage: LadderOperatorProductTerm.FromTuples

Returns: (LadderOperatorUnit * uint32) array -> LadderOperatorProductTerm
Returns: (LadderOperatorUnit * uint32) array -> LadderOperatorProductTerm

LadderOperatorProductTerm.FromUnits

Full Usage: LadderOperatorProductTerm.FromUnits

Returns: (bool * uint32) array -> LadderOperatorProductTerm
Returns: (bool * uint32) array -> LadderOperatorProductTerm

LadderOperatorProductTerm.TryCreateFromString(s)

Full Usage: LadderOperatorProductTerm.TryCreateFromString(s)

Parameters:
Returns: LadderOperatorProductTerm option
s : String
Returns: LadderOperatorProductTerm option

Type something to start searching.