Header menu logo Encodings

LadderOperatorSumExpression Type

Represents a sum of ladder operator product terms.

A sum expression represents the sum of multiple product terms:

c₁ · (product₁) + c₂ · (product₂) + ...

Sum expressions support addition and multiplication, and can be checked to verify all constituent terms are in normal/index order.

This is the primary type for representing fermionic Hamiltonians before encoding to qubit operators.

Union cases

Union case Description

LadderSum SIxOp<uint32, LadderOperatorUnit>

Full Usage: LadderSum SIxOp<uint32, LadderOperatorUnit>

Parameters:
Item : SIxOp<uint32, LadderOperatorUnit>

Instance members

Instance member Description

this.AllTermsIndexOrdered

Full Usage: this.AllTermsIndexOrdered

Returns: bool
Returns: bool

this.AllTermsNormalOrdered

Full Usage: this.AllTermsNormalOrdered

Returns: bool
Returns: bool

this.Coeff

Full Usage: this.Coeff

Returns: Complex
Returns: Complex

this.ProductTerms

Full Usage: this.ProductTerms

Returns: LadderOperatorProductTerm array

this.Reduce

Full Usage: this.Reduce

Returns: Lazy<LadderOperatorSumExpression>

this.Unapply

Full Usage: this.Unapply

Returns: S<IxOp<uint32, LadderOperatorUnit>>
Returns: S<IxOp<uint32, LadderOperatorUnit>>

Static members

Static member Description

LadderOperatorSumExpression.TryCreateFromString

Full Usage: LadderOperatorSumExpression.TryCreateFromString

Returns: String -> LadderOperatorSumExpression option

Type something to start searching.