Header menu logo Encodings

IndexOrder Type

Specifies the ordering direction for indexed operators.

Used to validate or enforce a particular ordering of operator indices in product terms. Ascending order (0, 1, 2, ...) is common for Pauli strings, while descending may be used in other contexts.

Union cases

Union case Description

Ascending

Full Usage: Ascending

Indices should be in ascending order (0, 1, 2, ...).

Descending

Full Usage: Descending

Indices should be in descending order (..., 2, 1, 0).

Instance members

Instance member Description

this.IsAscending

Full Usage: this.IsAscending

Returns: bool
Returns: bool

this.IsDescending

Full Usage: this.IsDescending

Returns: bool
Returns: bool

Type something to start searching.