Header menu logo Encodings

MeasurementBasis Type

A measurement basis for simultaneous measurement of commuting Pauli terms.

In VQE, terms that qubit-wise commute can be measured simultaneously in a single basis rotation circuit, reducing the total number of measurement circuits needed.

Record fields

Record Field Description

BasisRotation

Full Usage: BasisRotation

Field type: Pauli[]

Basis rotation needed for each qubit (I = computational basis).

Field type: Pauli[]

Terms

Full Usage: Terms

Field type: PauliRegister[]

Hamiltonian terms measurable in this basis.

Field type: PauliRegister[]

Weight

Full Usage: Weight

Field type: float

Sum of |coefficients| for shot allocation weighting.

Field type: float

Type something to start searching.