LadderOperatorProductTerm Type
Represents a product of indexed fermionic ladder operators with a coefficient.
A product term represents an expression like c · a†ᵢ a†ⱼ aₖ aₗ where c is a complex coefficient.
Product terms can be multiplied together and checked for normal/index ordering.
Example string format: "(1+0i)[u0 u1 d3 d2]" for a†₀ a†₁ a₃ a₂
Union cases
| Union case |
Description
|
Full Usage:
LadderProduct PIxOp<uint32, LadderOperatorUnit>
Parameters:
PIxOp<uint32, LadderOperatorUnit>
|
|
Instance members
| Instance member |
Description
|
|
|
Full Usage:
this.IsInIndexOrder
Returns: bool
|
|
Full Usage:
this.IsInNormalOrder
Returns: bool
|
|
|
|
|
|
|
|
Static members
| Static member |
Description
|
Full Usage:
arg0 * arg1
Parameters:
LadderOperatorProductTerm
arg1 : LadderOperatorProductTerm
Returns: LadderOperatorProductTerm
|
|
Full Usage:
LadderOperatorProductTerm.FromTuples
Returns: (LadderOperatorUnit * uint32) array -> LadderOperatorProductTerm
|
|
Full Usage:
LadderOperatorProductTerm.FromUnits
Returns: (bool * uint32) array -> LadderOperatorProductTerm
|
|
Full Usage:
LadderOperatorProductTerm.TryCreateFromString(s)
Parameters:
String
Returns: LadderOperatorProductTerm option
|
|