LadderOperatorSumExpression Type
Represents a sum of ladder operator product terms.
A sum expression represents the sum of multiple product terms:
c₁ · (product₁) + c₂ · (product₂) + ...
Sum expressions support addition and multiplication, and can be checked to verify all constituent terms are in normal/index order.
This is the primary type for representing fermionic Hamiltonians before encoding to qubit operators.
Union cases
| Union case |
Description
|
Full Usage:
LadderSum SIxOp<uint32, LadderOperatorUnit>
Parameters:
SIxOp<uint32, LadderOperatorUnit>
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AllTermsIndexOrdered
Returns: bool
|
|
Full Usage:
this.AllTermsNormalOrdered
Returns: bool
|
|
|
|
|
|
|
|
|
|
Static members
| Static member |
Description
|
Full Usage:
arg0 * arg1
Parameters:
LadderOperatorSumExpression
arg1 : LadderOperatorSumExpression
Returns: LadderOperatorSumExpression
|
|
Full Usage:
arg0 + arg1
Parameters:
LadderOperatorSumExpression
arg1 : LadderOperatorSumExpression
Returns: LadderOperatorSumExpression
|
|
Full Usage:
LadderOperatorSumExpression.TryCreateFromString
Returns: String -> LadderOperatorSumExpression option
|
|