IndexOrder Type
Specifies the ordering direction for indexed operators.
Used to validate or enforce a particular ordering of operator indices in product terms. Ascending order (0, 1, 2, ...) is common for Pauli strings, while descending may be used in other contexts.
Union cases
| Union case |
Description
|
Full Usage:
Ascending
|
Indices should be in ascending order (0, 1, 2, ...). |
Full Usage:
Descending
|
Indices should be in descending order (..., 2, 1, 0). |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAscending
Returns: bool
|
|
Full Usage:
this.IsDescending
Returns: bool
|
|