SIxOp<'idx, 'op> Type
A sum of products of indexed operators, representing a linear combination.
SIxOp wraps a sum expression (S) of indexed operator products. This is the most general form of a quantum operator in this library, capable of representing Hamiltonians as sums of Pauli strings or fermionic terms.
Example: H = 0.5 X₀Z₁ + 0.3 Y₀Y₁ - 0.2 Z₀
Union cases
| Union case |
Description
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AllTermsIndexOrdered
Parameters:
IndexOrder
-
The expected ordering direction.
Returns: Lazy<bool>
A lazy boolean that is true if all terms satisfy the ordering.
|
Lazily checks whether all product terms have indices in the specified order.
|
|
|
|
Static members
| Static member |
Description
|
|